//
//  ContentView.swift
//  awesome
//
//  Created by Pete Keleher on 9/23/21.
//

import SwiftUI

struct ButtonView : View {
    @State var buttonText = "Push me"
    @State private var isSet = false
    
    var body: some View {
        Button(action: f) {
            Text(buttonText)
        }
    }

    func f() {
        if isSet {
            buttonText = "re-push me"
        } else {
            buttonText = "you did it"
        }
        isSet = !isSet
    }
}

struct ButtonAlert : View {
    @State private var showAlert = false
    @State private var buttonText = "Push me"
    
    var body: some View {
        Button(buttonText) {
            showAlert = true
        }.actionSheet(isPresented: $showAlert) {
            ActionSheet(
                title: Text("This is an alert"),
                message: Text("you rang"),
                buttons: [
                    .cancel(),
                        .default(Text("foo"), action: {
                            buttonText = "foo"
                        }),
                        .destructive(Text("bar"),action: {
                            buttonText = "bar"
                        })
                ]
            )
        }
    }
}

struct ToggleView : View {
    @State private var isOn = false
    private var yes = "yes"
    private var no = "no"
    
    var body: some View {
        VStack {
            Toggle(isOn: $isOn, label: {
                Text("Is it on?")
            })
            .padding()
            .border(Color.black, width: 1)
            Text("\(isOn ? "yes" : "no")")
        }
    }
}

struct menuView : View {
    var body: some View {
        Menu {
            Button("one", action: {})
            Button("two", action: {})
            Menu("3D") {
                Button("four", action: {})
                Button("five", action: {})
            }
        } label: {
            Text("Help me")
        }
    }
}

struct GestureView : View {
    @State var tapped = ""
    
    var tap: some Gesture {
        TapGesture(count: 1)
            .onEnded { self.tapped = "Tapped!"}
    }
    
    var body: some View {
        HStack {
            Text("tap me!").gesture(tap)
            Text(tapped)
            Text("Reset").onTapGesture(count: 2) {
                self.tapped = ""
            }
        }
    }
}

struct ContentView: View {
    var body: some View {
        TabView {
            ButtonView().tabItem({ Text("Button1") })
                .padding()
            ButtonAlert().tabItem({ Text("ButtonAlert") })
                .padding()
            ToggleView().tabItem({ Text("Toggle") })
                .padding()
            menuView().tabItem({ Text("Menu") })
                .padding()
            GestureView().tabItem({ Text("Gesture") })
                .padding()
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
